# bpnet-lite
# Author: Jacob Schreiber
# Code adapted from Avanti Shrikumar and Ziga Avsec

from .bpnet import BPNet

__version__ == '0.0.2'
